GeminiModel class

Inheritance

Constructors

GeminiModel()

Properties

defaultAIRequestModel → AIRequestModel
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRequest(AIRequestModel? aiRequestModel) → HttpRequestModel?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outputFormatter(Map x) → String?
override
streamOutputFormatter(Map x) → String?
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → GeminiModel
final